{
  modulesPath,
  lib,
  nixos-hardware,
  ...
}:

{
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
    nixos-hardware.nixosModules.raspberry-pi-4
  ];

  boot = {
    initrd = {
      availableKernelModules = [ "xhci_pci" ];
    };
    loader = {
      generic-extlinux-compatible.enable = true;
    };
  };

  fileSystems."/" = {
    device = "/dev/disk/by-uuid/44444444-4444-4444-8888-888888888888";
    fsType = "ext4";
  };

  hardware.raspberry-pi."4".fkms-3d.enable = true;

  networking = {
    useDHCP = lib.mkDefault true;
  };

  powerManagement.cpuFreqGovernor = "ondemand";

  networking.firewall = {
    enable = true;
    allowedTCPPorts = [ 80 443 53 ];
    allowedUDPPorts = [ 80 443 53 ];
  };

  services.nginx = {
    enable = true;
  };

  services.dnsmasq = {
    enable = true;
    settings = {
      server = [
        "8.8.8.8"
        "8.8.4.4"
      ];
      #dhcp-range = [ "192.168.0.2,192.168.0.254,5m" ];
      #dhcp-option= [ "3,0.0.0.0" "6,0.0.0.0" ];

      #domain-needed = true;
    };
  };

  services.mediawiki = {
    enable = true;
    webserver = "nginx";
    url = "http://wiki.it3";
    nginx.hostName = "wiki.it3";
    passwordFile = "${../../init/mediawiki}";
  };
}
